<html>
  <head>

    <style>

    </style>

    {% include "mustachebox/includes/jsheader.html" %}
    <script type="text/javascript">
      var data = {% autoescape off %}{{object.data}}{% endautoescape %}
      var width = 860;
      var height = 300;
      var margin = {top: 20, right: 20, bottom: 30, left: 50};
    </script>

  </head>
  <body>
<script type="text/javascript" src="{{STATIC_URL}}js/d3_multiline_chart.js"></script>
  </body>
</html>
