<!doctype html>
<html>
  <head>
    <title>{% block title %}{% endblock %} | graph</title>
    <link rel=stylesheet href=/static/css/style.css type=text/css>
    {% block js %}{% endblock %}
  </head>
  <body>
    <div class="box">
      <h1><a href=/>All Graphs</a></h1>
<p class=tagline>A Graph Application</p>
{% block body %}{% endblock %}
</div>
</body>
</html>
