<html>
  <head>
    <script type="text/javascript"
    src="https://www.google.com/jsapi"></script>
<script type="text/javascript">
      var data = {% autoescape off %}{{object.data}}{% endautoescape %}
</script>
    <script type="text/javascript" src="{{STATIC_URL}}js/time_serie.js"></script>
    <script type="text/javascript" src="{{STATIC_URL}}js/columnchart.js"></script>
  </head>
  <body>
        <div id="columnchart_div" style="width: 900px; height: 500px;"></div>

  </body>
</html>

