<html>
  <head>

<style>

body {
  font: 10px sans-serif;
}

.axis path,
.axis line {
  fill: none;
  stroke: #000;
  shape-rendering: crispEdges;
}

.x.axis path {
  display: none;
}

.line {
  fill: none;
  stroke: steelblue;
  stroke-width: 1.5px;
}

</style>

    {% include "mustachebox/includes/jsheader.html" %}
    <script type="text/javascript">
      var data = {% autoescape off %}{{object.data}}{% endautoescape %}
      var width = 960;
      var height = 500;
      var margin = {top: 20, right: 20, bottom: 30, left: 50};
    </script>

  </head>
  <body>
<script type="text/javascript" src="{{STATIC_URL}}js/d3_line_chart.js"></script>
  </body>
</html>
