<script type="text/javascript"
    src="https://www.google.com/jsapi"></script>
<script type="text/javascript">
      var piedata = {% autoescape off %}{{object.data}}{% endautoescape %}
</script>
<script type="text/javascript" src="{{STATIC_URL}}js/pie_chart.js"></script>

<div id="piechart_div" style="width: 300px; height: 300px;"></div>
