<script type="text/javascript" src="{{STATIC_URL}}js/d3.v2.js">
</script>
<script type="text/javascript" src="{{STATIC_URL}}js/jquery.js">
</script>
<script type="text/javascript">
  var name = "{{object.name}}"
</script>
