{% load graph %}
{% for obj in object_list %}
<div class="graph">
  <h3><a href={% url graph obj.name %}>{{obj.name}}</a></h3>
  <p>

{{obj.doc|parse_docstring}}

</p>
  <div>
    <h4>Exemple</h4>
    {% graph obj.name %}
  </div>
</div>
{% endfor %}
